**Feature**

*MSFT-1238 Token Authentication*

- Update authentication docs [Artur Barseghyan]
- Implement token authentication [Artur Barseghyan]

*MSFT-1237 Improve Document Sharing*

- Improve document sharing. Add option to share via GDrive [Artur Barseghyan]

*MSFT-1234 Car Type Suggester*

- Add insurance amount indication based on car weight [Artur Barseghyan]
- Initial car type suggester implementation [Artur Barseghyan]

**Bugfix**

*MSFT-1236 Prevent Duplicate Postal Codes*

- Make postal code field unique for the country [Artur Barseghyan]
- Normalise postal codes for US addresses [Artur Barseghyan]
- Normalise postal codes for German addresses [Artur Barseghyan]

**Deprecation**

*MSFT-1235 Deprecate Old Api*

- Update docs [Artur Barseghyan]
- Deprecate API v 2.0 [Artur Barseghyan]
